@@ -32,11 +32,16 @@
 #include <signal.h>
 #include <string.h>
 #include <math.h>
+#include <assert.h>
 
 /* GTK+ headers */
 #include <gtk/gtk.h>
 #include <glib.h>
 
+#ifdef USE_DMALLOC
+#include <dmalloc.h>
+#endif
+
 /* own headers */
 #include "globals.h"
 #include "metro.h"
@@ -188,7 +193,7 @@ static int is_in_range_of_index_name(int speed, int index) {
 }
 
 /*
- * Called whenever
+ * Called whenever tap button is clicked
  */
 static void tap_cb(metro_t* metro)
 {
@@ -196,6 +201,8 @@ static void tap_cb(metro_t* metro)
   struct timeval diffval;
   double timediff;
 
+  assert(metro != NULL);
+
   gettimeofday(&thistime, NULL);
   
   timeval_subtract(&diffval, &thistime, &metro->lasttap);
@@ -1648,7 +1655,7 @@ metro_t* metro_new(void) {
   
   /* Timing UI Code */
   
-  beatframe = gtk_frame_new (_("Beat"));
+  beatframe = gtk_frame_new (_("Meter"));
   gtk_frame_set_shadow_type(GTK_FRAME(beatframe), GTK_SHADOW_NONE);
   label = gtk_frame_get_label_widget(GTK_FRAME(beatframe));
   gtk_label_attr_bold(GTK_LABEL(label));
